﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using System.Windows.Browser;

namespace SilverlightExample
{
	[ScriptableType]
	public partial class MainPage : UserControl
	{       private System.Windows.Threading.DispatcherTimer timer;
        private double stepSize = 3;

        public MainPage()
        {
            InitializeComponent();

			HtmlPage.RegisterScriptableObject("SilverlightTestSample", this);

            stepSizeInput.NumberFormatInfo.NumberDecimalDigits = 1;
            minValue.NumberFormatInfo.NumberDecimalDigits = 1;
            maxValue.NumberFormatInfo.NumberDecimalDigits = 1;
            stepSizeInput.NumberFormatInfo.NumberGroupSeparator = " ";
            minValue.NumberFormatInfo.NumberGroupSeparator = " ";
            maxValue.NumberFormatInfo.NumberGroupSeparator = " ";
        }

        private void Configuration_Loaded(object sender, RoutedEventArgs e)
        {
            stepSizeInput.Minimum = pb.Minimum;
            stepSizeInput.Maximum = pb.Maximum;
            stepSizeInput.SmallChange = this.stepSize;
            stepSizeInput.LargeChange = stepSizeInput.SmallChange * 2;
            stepSizeInput.Value = this.stepSize;

            minValue.Minimum = 0;
            minValue.Maximum = Double.MaxValue;
            minValue.SmallChange = this.stepSize;
            minValue.Value = pb.Minimum;

            maxValue.Minimum = minValue.Value;
            maxValue.Maximum = Double.MaxValue;
            maxValue.SmallChange = this.stepSize;
            maxValue.Value = pb.Maximum;

            this.timer = new System.Windows.Threading.DispatcherTimer();
            this.timer.Interval = TimeSpan.FromMilliseconds(10.0);
            this.timer.Tick += new EventHandler(this.Timer_Tick);
            this.timer.Start();
        }

		[ScriptableMember]
        private void Timer_Tick(object sender, EventArgs e)
        {
            pb.Value += this.stepSize;
            int value = Math.Max(0, Math.Min(100, Convert.ToInt32((pb.Value / (pb.Maximum - pb.Minimum)) * 100)));
            loadingPercentage.Text = value.ToString() + " %";

            if (Convert.ToInt32((pb.Value / (pb.Maximum - pb.Minimum) * 100)) == 100)
            {
                loadingText.Text = "Loaded    ";
				HtmlPage.Window.Invoke("test");
				this.timer.Stop();
            }
        }

		[ScriptableMember]
		public void UpdateSilverlightText(string newText)
		{
			loadingText.Text = newText;
		}

        private void Btn_stop_Click(object sender, RoutedEventArgs e)
        {
            this.timer.Stop();
        }

        private void Btn_start_Click(object sender, RoutedEventArgs e)
        {
            this.timer.Start();
        }

        private void Btn_restart_Click(object sender, RoutedEventArgs e)
        {
            this.timer.Stop();
            pb.Value = pb.Minimum;
            this.timer.Start();
            loadingText.Text = "Loading... ";
        }

        private void Horizontal_btn_Checked(object sender, RoutedEventArgs e)
        {
            if (pb != null && pb.Orientation == Orientation.Vertical)
            {
                vertical_btn.IsChecked = false;

                pb.Height = 30;
                pb.Width = 200;
                pb.Orientation = Orientation.Horizontal;
            }
        }

        private void Vertical_btn_Checked(object sender, RoutedEventArgs e)
        {
            if (pb != null && pb.Orientation == Orientation.Horizontal)
            {
                horizontal_btn.IsChecked = false;

                pb.Height = 200;
                pb.Width = 30;
                pb.Orientation = Orientation.Vertical;
            }
        }

        private void StepSizeInput_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            RadNumericUpDown tb = sender as RadNumericUpDown;
            if (tb.ContentText != String.Empty)
            {
                stepSize = tb.Value;
            }
        }

        private void MinValue_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            RadNumericUpDown tb = sender as RadNumericUpDown;
            if (tb.ContentText != String.Empty)
            {
                if (tb.Value < pb.Maximum)
                {
                    pb.Minimum = tb.Value;
                }
                else
                {
                    tb.Value = e.OldValue;
                }
            }
        }

        private void MaxValue_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            RadNumericUpDown tb = sender as RadNumericUpDown;
            if (tb.ContentText != String.Empty)
            {
                if (tb.Value > pb.Minimum)
                {
                    pb.Maximum = tb.Value;
                }
                else
                {
                    tb.Value = e.OldValue;
                }
            }
        }

		private void chbIsIndeterminate_Checked(object sender, RoutedEventArgs e)
		{
			pb.IsIndeterminate = true;
		}

		private void chbIsIndeterminate_Unchecked(object sender, RoutedEventArgs e)
		{
			pb.IsIndeterminate = false;
		}
    }

}
